self.__BUILD_MANIFEST=function(s,c,e,a,t,f,u,n,r,b,i,d,j,k,o){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-89e7daf7b7df02e0.js"],"/_error":["static/chunks/pages/_error-c72a1f77a3c0be1b.js"],"/clusters":["static/chunks/pages/clusters-3d4be4961e1c94eb.js"],"/clusters/[cluster]":[s,c,e,a,t,r,i,f,u,n,d,b,j,k,o,"static/chunks/1871-ea0e7283886407ca.js","static/chunks/pages/clusters/[cluster]-95afb019ab85801c.js"],"/clusters/[cluster]/[job]":[s,c,e,a,t,f,u,n,"static/chunks/pages/clusters/[cluster]/[job]-2186770cc2de1623.js"],"/config":["static/chunks/pages/config-a2673b256b6d416f.js"],"/infra":["static/chunks/pages/infra-0d3d1f890c5d188a.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-a90b4fe4616dc501.js"],"/jobs":["static/chunks/pages/jobs-49f790d12a85027c.js"],"/jobs/[job]":[s,c,e,a,t,r,f,u,n,b,"static/chunks/pages/jobs/[job]-dc0299ffefebcdbe.js"],"/users":["static/chunks/pages/users-6790fcefd5487b13.js"],"/volumes":["static/chunks/pages/volumes-61ea7ba7e56f8d06.js"],"/workspace/new":["static/chunks/pages/workspace/new-5629d4e551dba1ee.js"],"/workspaces":["static/chunks/pages/workspaces-5f7fe4b7d55b8612.js"],"/workspaces/[name]":[s,c,e,a,t,r,i,f,u,n,d,b,j,k,o,"static/chunks/1141-e49a159c30a6c4a7.js","static/chunks/pages/workspaces/[name]-6bcd4b20914d76c9.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/[job]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/616-162f3033ffcd3d31.js","static/chunks/5230-df791914b54d91d9.js","static/chunks/5739-5ea3ffa10fc884f2.js","static/chunks/1664-d65361e92b85e786.js","static/chunks/7411-2cc31dc0fdf2a9ad.js","static/chunks/6989-eab0e9c16b64fd9f.js","static/chunks/3698-9fa11dafb5cad4a6.js","static/chunks/6135-2abbd0352f8ee061.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/8969-8e0b2055bf5dd499.js","static/chunks/1559-18717d96ef2fcbe9.js","static/chunks/6990-f64e03df359e04f7.js","static/chunks/1043-869d9c78bf5dd3df.js","static/chunks/6601-d4a381403a8bae91.js","static/chunks/938-7ee806653aef0609.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();